.. _output_structure:

Output Structure
================

.. module:: nani
   :noindex:

.. autosummary::
   :nosignatures:

   Nani


This regroups the output structure from the main routine :func:`~nani.resolve`.
The :class:`Nani` object regroups the properties helping to define NumPy's
arrays and to optionally wrap them into an abstraction layer.


.. autoclass:: Nani(dtype, default, view)
